==> python_cassandra_cli-1.1.0-py3-none-any.whl: python_cassandra_cli/constants.py <==
# constants with _OPTONS is used for storing help info in @click options
KEYSPACE_OPTION = 'Keyspace name from which take a snapshot'
SNAPSHOT_TAG_OPTION = 'Snapshot tag name'
S3_BUCKET_OPTION = 'S3 bucket for/with a snapshot'
AWS_ACCESS_KEY_ID_OPTION = 'AWS access key id'
AWS_SECRET_ACCESS_KEY_OPTION = 'AWS secret access key'
AWS_REGION_OPTION = 'AWS region'
ENVIRONMENT_OPTION = 'Identification Cassandra cluster environment. Example: dev, prod'
CASSANDRA_HOST_OPTION = 'Cassandra host name or ip'
CASSANDRA_USER_OPTION = 'Cassandra user name'
CASSANDRA_PASSWORD_OPTION = 'Cassandra password'
CASSANDRA_PORT_OPTION = 'Cassandra port'
CASSANDRA_CONFIG_FILE_OPTION = 'Cassandra config file'
CASSANDRA_KEYSTORE_OPTION = 'Cassandra keystore path'
CASSANDRA_TRUSTSTORE_OPTION = 'Cassandra truststore path'
NO_CLEAR_SNAOSHOT_OPTION = 'If set this flag CLI does not remove the snapshot with the given tag name'
SSM_SECRET_OPTION = 'Get Cassandra login and password from AWS SSM Parameter Store'
SECRET_NAME_OPTION = 'AWS Parameter Store secret name'
TABLE_NAME_OPTION = 'Cassandra table name for storing'
CREATE_KEYSPACE_SCHEMA_OPTION = 'Set this flag if you want to take keyspace schema'
CREATE_TABLE_SCHEMA_OPTION = 'Set this flag if you want to take table schema'
SNAPSHOT_FOLDER_OPTION = 'Folder name on S3 that includes snapshots'
SSL_CONNECTION_OPTION = 'Set this flag when Cassandra has SSL enabled'
SSL_CONNECTION_CQLSH_OPTION = 'Set this flag when only SSL connection to Cassandra; sets --ssl frag for cqlsh'
SNAPSHOT_FOLDER_S3_OVERRIDE_OPTION = 'Override folder name in S3 that includes snapshots, without flag folder name has format <time stamp>_snapshots_<tag name>_<keyspace name>_<environment>'

INITIAL_MESSAGE = 'Command is executing ... '

==> python_cassandra_cli-1.2.1-py3-none-any.whl: python_cassandra_cli/constants.py <==
# constants with _OPTONS is used for storing help info in @click options
KEYSPACE_OPTION = 'Keyspace name from which take a snapshot'
SNAPSHOT_TAG_OPTION = 'Snapshot tag name'
S3_BUCKET_OPTION = 'S3 bucket for/with a snapshot'
AWS_ACCESS_KEY_ID_OPTION = 'AWS access key id'
AWS_SECRET_ACCESS_KEY_OPTION = 'AWS secret access key'
AWS_REGION_OPTION = 'AWS region'
ENVIRONMENT_OPTION = 'Identification Cassandra cluster environment. Example: dev, prod'
CASSANDRA_HOST_OPTION = 'Cassandra host name or ip'
CASSANDRA_USER_OPTION = 'Cassandra user name'
CASSANDRA_PASSWORD_OPTION = 'Cassandra password'
CASSANDRA_PORT_OPTION = 'Cassandra port'
CASSANDRA_CONFIG_FILE_OPTION = 'Cassandra config file'
CASSANDRA_KEYSTORE_OPTION = 'Cassandra keystore path'
CASSANDRA_TRUSTSTORE_OPTION = 'Cassandra truststore path'
NO_CLEAR_SNAOSHOT_OPTION = 'If set this flag CLI does not remove the snapshot with the given tag name'
SSM_SECRET_OPTION = 'Get Cassandra login and password from AWS SSM Parameter Store'
SECRET_NAME_OPTION = 'AWS Parameter Store secret name'
TABLE_NAME_OPTION = 'Cassandra table name for storing'
CREATE_KEYSPACE_SCHEMA_OPTION = 'Set this flag if you want to take keyspace schema'
CREATE_TABLE_SCHEMA_OPTION = 'Set this flag if you want to take table schema'
SNAPSHOT_FOLDER_OPTION = 'Folder name on S3 that includes snapshots'
SSL_CONNECTION_OPTION = 'Set this flag when Cassandra has SSL enabled'
SSL_CONNECTION_CQLSH_OPTION = 'Set this flag when only SSL connection to Cassandra; sets --ssl frag for cqlsh'
SNAPSHOT_FOLDER_S3_OVERRIDE_OPTION = 'Override folder name in S3 that includes snapshots, without flag folder name has format <time stamp>_snapshots_<tag name>_<keyspace name>_<environment>'
KEYSTORE_PASSWORD_OPTION = 'Client SSL: password of the keystore'
TRUSTSTORE_PASSWORD_OPTION = 'Client SSL: password of the truststore'
INITIAL_MESSAGE = 'Command is executing ... '
